==> apache-superset-3.0.2-source.tar.gz: apache-superset-3.0.2rc2/superset-frontend/plugins/plugin-chart-echarts/CHANGELOG.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.18.0](https://github.com/apache-superset/superset-ui/compare/v0.17.87...v0.18.0) (2021-08-30)

**Note:** Version bump only for package @superset-ui/plugin-chart-echarts





## [0.17.63](https://github.com/apache-superset/superset-ui/compare/v0.17.62...v0.17.63) (2021-07-02)

**Note:** Version bump only for package @superset-ui/plugin-chart-echarts





## [0.17.61](https://github.com/apache-superset/superset-ui/compare/v0.17.60...v0.17.61) (2021-07-02)


### Bug Fixes

* **plugin-chart-echarts:** enable animation to clear old nodes ([#1200](https://github.com/apache-superset/superset-ui/issues/1200)) ([1ee7f4e](https://github.com/apache-superset/superset-ui/commit/1ee7f4e36e1245917e61999f190a84425e82ea38))
* **plugin-chart-echarts:** sanitize series from html tags ([#1126](https://github.com/apache-superset/superset-ui/issues/1126)) ([fcd6fde](https://github.com/apache-superset/superset-ui/commit/fcd6fde44bb45df3aab5ac5bb990504e7dbde324))

==> apache-superset-4.1.2-source.tar.gz: apache-superset-4.1.2rc1/superset-frontend/plugins/plugin-chart-echarts/CHANGELOG.md <==
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.18.0](https://github.com/apache-superset/superset-ui/compare/v0.17.87...v0.18.0) (2021-08-30)

**Note:** Version bump only for package @superset-ui/plugin-chart-echarts

## [0.17.63](https://github.com/apache-superset/superset-ui/compare/v0.17.62...v0.17.63) (2021-07-02)

**Note:** Version bump only for package @superset-ui/plugin-chart-echarts

## [0.17.61](https://github.com/apache-superset/superset-ui/compare/v0.17.60...v0.17.61) (2021-07-02)

### Bug Fixes

- **plugin-chart-echarts:** enable animation to clear old nodes ([#1200](https://github.com/apache-superset/superset-ui/issues/1200)) ([1ee7f4e](https://github.com/apache-superset/superset-ui/commit/1ee7f4e36e1245917e61999f190a84425e82ea38))
- **plugin-chart-echarts:** sanitize series from html tags ([#1126](https://github.com/apache-superset/superset-ui/issues/1126)) ([fcd6fde](https://github.com/apache-superset/superset-ui/commit/fcd6fde44bb45df3aab5ac5bb990504e7dbde324))
